@@ -28,6 +28,7 @@ from fss_utils.jwt_manager import JWTManager, ValidateCode
 from fss_utils.vouch_encoder import VouchEncoder, CustomClaimsType, PTokens
 
 from fabric_cm.credmgr.config import CONFIG_OBJ
+from fabric_cm.credmgr.external_apis.ldap import CmLdapMgrSingleton
 from fabric_cm.credmgr.logging import LOG
 from fabric_cm.credmgr.common.exceptions import TokenError
 from fabric_cm.credmgr.external_apis.project_registry import ProjectRegistry
@@ -39,7 +40,7 @@ class FabricTokenEncoder:
     by adding the project, scope and membership information to the token
     and signing with Fabric Certificate
     """
-    def __init__(self, id_token, idp_claims: dict, project="all", scope="all", cookie: str = None):
+    def __init__(self, id_token, idp_claims: dict, project:str, scope="all", cookie: str = None):
         """
         Constructor
         :param id_token: CI Logon Identity Token
@@ -134,24 +135,20 @@ class FabricTokenEncoder:
         """
         sub = self.claims.get("sub")
         url = CONFIG_OBJ.get_pr_url()
-        project_registry = ProjectRegistry(api_server=url, cookie=self._get_vouch_cookie(),
-                                           cookie_name=CONFIG_OBJ.get_vouch_cookie_name(),
-                                           cookie_domain=CONFIG_OBJ.get_vouch_cookie_domain_name())
-        roles, projects = project_registry.get_projects_and_roles(sub)
 
-        LOG.debug("Projects: %s, Roles: %s", projects, roles)
+        if CONFIG_OBJ.is_project_registry_enabled():
+            project_registry = ProjectRegistry(api_server=url, cookie=self._get_vouch_cookie(),
+                                               cookie_name=CONFIG_OBJ.get_vouch_cookie_name(),
+                                               cookie_domain=CONFIG_OBJ.get_vouch_cookie_domain_name())
+            roles, project_tags = project_registry.get_roles_and_project_tags(sub, project_id=self.project)
+        else:
+            email = self.claims.get("email")
+            roles, project_tags = CmLdapMgrSingleton.get().get_roles_and_project_tags(eppn=None,
+                                                                                      email=email,
+                                                                                      project_id=self.project)
 
-        projects_to_be_removed = []
-        for project in projects.keys():
-            LOG.debug("Processing %s", project)
-            if self.project != "all" and self.project not in project:
-                projects_to_be_removed.append(project)
-        for x in projects_to_be_removed:
-            projects.pop(x)
-
-        if len(projects) < 1:
-            raise TokenError("User is not a member of any of the project")
-        self.claims['projects'] = projects
+        LOG.debug("Project Tags: %s, Roles: %s", project_tags, roles)
+        self.claims['projects'] = {self.project: project_tags}
         self.claims["roles"] = roles
         self.claims["scope"] = self.scope
         LOG.debug("Claims %s", self.claims)
